Running GO-PCA: ``go-pca.py``
-----------------------------

.. ".. code-block:: bash
    
    go-pca.py -g [gene_file] -a [annotation_file] -t [ontology_file] -e [expression_file] -o [output_file]

.. argparse::
   :ref: gopca.main.get_argument_parser
   :prog: go-pca.py
